@@ -21,6 +21,7 @@ import org.gcube.portlets.user.td.resourceswidget.client.charts.ChartViewerDialo
 import org.gcube.portlets.user.td.resourceswidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.resourceswidget.client.save.SaveResourceWizard;
 import org.gcube.portlets.user.td.resourceswidget.client.utils.UtilsGXT3;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
@@ -200,18 +201,25 @@ public class ResourcesListViewPanel extends FramedPanel {
 	private Menu contextMenu;
 	private MenuItem openItem;
 	private MenuItem saveItem;
-	private MenuItem removeItem;
+	private MenuItem deleteItem;
 	private RemoveResourceSession removeResourceSession;
 	private SaveResourceSession saveResourceSession;
 	private ToolBar statusBar;
+	private CommonMessages msgsCommon;
+	private ResourcesMessages msgs;
 
 	public ResourcesListViewPanel(EventBus eventBus) {
 		super();
 		this.eventBus = eventBus;
-		forceLayoutOnResize = true;
+		initMessages();
 		init();
 		create();
 	}
+	
+	protected void initMessages(){
+		msgs = GWT.create(ResourcesMessages.class);
+		msgsCommon = GWT.create(CommonMessages.class);
+	}
 
 	public void open(TRId trId) {
 		try {
@@ -226,6 +234,7 @@ public class ResourcesListViewPanel extends FramedPanel {
 	}
 
 	protected void init() {
+		forceLayoutOnResize = true;
 		setHeaderVisible(false);
 		setBodyBorder(false);
 		setResize(true);
@@ -300,10 +309,10 @@ public class ResourcesListViewPanel extends FramedPanel {
 		filterField.bind(store);
 
 		ToolBar toolBar = new ToolBar();
-		toolBar.add(new LabelToolItem("Filter:"));
+		toolBar.add(new LabelToolItem(msgs.toolBarFilterLabel()));
 		toolBar.add(filterField);
 		toolBar.add(new SeparatorToolItem());
-		toolBar.add(new LabelToolItem("Sort By:"));
+		toolBar.add(new LabelToolItem(msgs.toolBarSortBy()));
 
 		comboSort = new SimpleComboBox<String>(
 				new StringLabelProvider<String>());
@@ -519,13 +528,12 @@ public class ResourcesListViewPanel extends FramedPanel {
 							} else {
 								if (caught instanceof TDGWTIsLockedException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Locked",
+									UtilsGXT3.alert(msgsCommon.errorLocked(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.error("Error Retrieving Resources: "
 											+ caught.getLocalizedMessage());
-									UtilsGXT3.alert(
-											"Error retrieving resources",
+									UtilsGXT3.alert(msgs.errorRetrievingResourcesHead(),
 											caught.getLocalizedMessage());
 								}
 							}
@@ -538,12 +546,10 @@ public class ResourcesListViewPanel extends FramedPanel {
 							if (result != null && result.size() > 0) {
 								statusBar.clear();
 								statusBar
-										.add(new LabelToolItem(
-												"Number of Resources: "
-														+ result.size()));
+										.add(new LabelToolItem(msgs.statusBarNumberOfResources(result.size())));
 							} else {
 								statusBar.clear();
-								statusBar.add(new LabelToolItem("No Resource"));
+								statusBar.add(new LabelToolItem(msgs.statusBarNoResource()));
 								
 							}
 							statusBar.forceLayout();
@@ -563,7 +569,7 @@ public class ResourcesListViewPanel extends FramedPanel {
 		contextMenu = new Menu();
 
 		openItem = new MenuItem();
-		openItem.setText("Open");
+		openItem.setText(msgs.itemOpenText());
 		openItem.setIcon(ResourceBundle.INSTANCE.resources());
 		openItem.addSelectionHandler(new SelectionHandler<Item>() {
 
@@ -582,7 +588,7 @@ public class ResourcesListViewPanel extends FramedPanel {
 		});
 
 		saveItem = new MenuItem();
-		saveItem.setText("Save");
+		saveItem.setText(msgs.itemSaveText());
 		saveItem.setIcon(ResourceBundle.INSTANCE.save());
 		saveItem.addSelectionHandler(new SelectionHandler<Item>() {
 
@@ -600,10 +606,10 @@ public class ResourcesListViewPanel extends FramedPanel {
 
 		});
 
-		removeItem = new MenuItem();
-		removeItem.setText("Delete");
-		removeItem.setIcon(ResourceBundle.INSTANCE.delete());
-		removeItem.addSelectionHandler(new SelectionHandler<Item>() {
+		deleteItem = new MenuItem();
+		deleteItem.setText(msgs.itemDeleteText());
+		deleteItem.setIcon(ResourceBundle.INSTANCE.delete());
+		deleteItem.addSelectionHandler(new SelectionHandler<Item>() {
 
 			@Override
 			public void onSelection(SelectionEvent<Item> event) {
@@ -633,41 +639,41 @@ public class ResourcesListViewPanel extends FramedPanel {
 					openItem.setIcon(ResourceBundle.INSTANCE.chart());
 					contextMenu.add(openItem);
 					contextMenu.add(saveItem);
-					contextMenu.add(removeItem);
+					contextMenu.add(deleteItem);
 					listView.setContextMenu(contextMenu);
 					break;
 				case CODELIST:
 					contextMenu.clear();
-					contextMenu.add(removeItem);
+					contextMenu.add(deleteItem);
 					listView.setContextMenu(contextMenu);
 					break;
 				case CSV:
 					contextMenu.clear();
 					contextMenu.add(saveItem);
-					contextMenu.add(removeItem);
+					contextMenu.add(deleteItem);
 					listView.setContextMenu(contextMenu);
 					break;
 				case GUESSER:
 					contextMenu.clear();
-					contextMenu.add(removeItem);
+					contextMenu.add(deleteItem);
 					listView.setContextMenu(contextMenu);
 					break;
 				case JSON:
 					contextMenu.clear();
 					contextMenu.add(saveItem);
-					contextMenu.add(removeItem);
+					contextMenu.add(deleteItem);
 					listView.setContextMenu(contextMenu);
 					break;
 				case MAP:
 					contextMenu.clear();
 					openItem.setIcon(ResourceBundle.INSTANCE.gis());
 					contextMenu.add(openItem);
-					contextMenu.add(removeItem);
+					contextMenu.add(deleteItem);
 					listView.setContextMenu(contextMenu);
 					break;
 				case SDMX:
 					contextMenu.clear();
-					contextMenu.add(removeItem);
+					contextMenu.add(deleteItem);
 					listView.setContextMenu(contextMenu);
 					break;
 				case GENERIC_FILE:
@@ -675,17 +681,17 @@ public class ResourcesListViewPanel extends FramedPanel {
 					openItem.setIcon(ResourceBundle.INSTANCE.file());
 					contextMenu.add(openItem);
 					contextMenu.add(saveItem);
-					contextMenu.add(removeItem);
+					contextMenu.add(deleteItem);
 					listView.setContextMenu(contextMenu);
 					break;
 				case GENERIC_TABLE:
 					contextMenu.clear();
-					contextMenu.add(removeItem);
+					contextMenu.add(deleteItem);
 					listView.setContextMenu(contextMenu);
 					break;
 				default:
 					contextMenu.clear();
-					contextMenu.add(removeItem);
+					contextMenu.add(deleteItem);
 					listView.setContextMenu(contextMenu);
 					event.setCancelled(true);
 					break;
@@ -744,7 +750,7 @@ public class ResourcesListViewPanel extends FramedPanel {
 			public void onSuccess() {
 
 				SaveResourceWizard saveResourceWizard = new SaveResourceWizard(
-						saveResourceSession, "Save Resource", eventBus);
+						saveResourceSession, msgs.saveResourceWizardHead(), eventBus);
 
 				saveResourceWizard.addListener(new WizardListener() {
 
@@ -795,13 +801,13 @@ public class ResourcesListViewPanel extends FramedPanel {
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								Log.error("Error removing the resource: "
 										+ caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error",
-										"Error removing the resource: "
+								UtilsGXT3.alert(msgsCommon.error(),
+										msgs.errorRemovingTheResource()
 												+ caught.getLocalizedMessage());
 							}
 						}
@@ -874,8 +880,8 @@ public class ResourcesListViewPanel extends FramedPanel {
 							} else {
 								Log.error("Error with uri resolver: "
 										+ caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error",
-										"Error retrieving uri from resolver");
+								UtilsGXT3.alert(msgsCommon.error(),
+										msgs.errorRetrievingURIFromResolver());
 							}
 						}
 
@@ -904,8 +910,8 @@ public class ResourcesListViewPanel extends FramedPanel {
 									Log.error("Error with uri resolver: "
 											+ caught.getLocalizedMessage());
 									UtilsGXT3
-											.alert("Error",
-													"Error retrieving uri from resolver");
+											.alert(msgsCommon.error(),
+													msgs.errorRetrievingURIFromResolver());
 								}
 							}
 
@@ -922,8 +928,8 @@ public class ResourcesListViewPanel extends FramedPanel {
 
 				} else {
 					Log.error("Error with resource: no valid resource");
-					UtilsGXT3.alert("Error with resource",
-							"Error no valid InternalUri");
+					UtilsGXT3.alert(msgsCommon.error(),
+							msgs.errorNoValidInternalUri());
 
 				}
 
@@ -985,8 +991,8 @@ public class ResourcesListViewPanel extends FramedPanel {
 							} else {
 								Log.error("Error with uri resolver: "
 										+ caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error",
-										"Error retrieving uri from resolver");
+								UtilsGXT3.alert(msgsCommon.error(),
+										msgs.errorRetrievingURIFromResolver());
 							}
 						}
 
@@ -1000,7 +1006,7 @@ public class ResourcesListViewPanel extends FramedPanel {
 		} else {
 			Log.error("Error with resource: no valid resource");
 			UtilsGXT3
-					.alert("Error with resource", "Error no valid InternalUri");
+					.alert(msgsCommon.error(), msgs.errorNoValidInternalUri());
 
 		}
 	}
