@@ -7,6 +7,7 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.gcube.portlets.user.td.gwtservice.shared.tr.resources.SaveResourceSession;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.wizardwidget.client.WizardCard;
 import org.gcube.portlets.widgets.wsexplorer.client.notification.WorkspaceExplorerSelectNotification.WorskpaceExplorerSelectNotificationListener;
 import org.gcube.portlets.widgets.wsexplorer.client.select.WorkspaceExplorerSelectPanel;
@@ -14,6 +15,7 @@ import org.gcube.portlets.widgets.wsexplorer.shared.Item;
 import org.gcube.portlets.widgets.wsexplorer.shared.ItemType;
 
 import com.allen_sauer.gwt.log.client.Log;
+import com.google.gwt.core.shared.GWT;
 import com.google.gwt.user.client.Command;
 import com.sencha.gxt.widget.core.client.FramedPanel;
 import com.sencha.gxt.widget.core.client.box.AlertMessageBox;
@@ -32,7 +34,7 @@ import com.sencha.gxt.widget.core.client.form.validator.EmptyValidator;
  * 
  */
 public class WorkSpaceSelectionCard extends WizardCard {
-
+	private static SaveResourceMessages msgs=GWT.create(SaveResourceMessages.class);
 	private SaveResourceSession saveResourceSession;
 	private WorkSpaceSelectionCard thisCard;
 	private TextField fileName;
@@ -40,10 +42,11 @@ public class WorkSpaceSelectionCard extends WizardCard {
 	
 	private VerticalLayoutContainer p;
 	private WorkspaceExplorerSelectPanel wpanel;
+	private CommonMessages msgsCommon;
 
 	public WorkSpaceSelectionCard(final SaveResourceSession saveResourceSession) {
-		super("Save in Workspace", "");
-
+		super(msgs.workspaceSelectionCardHead(), "");
+		initMessages();
 		this.saveResourceSession = saveResourceSession;
 		thisCard = this;
 
@@ -58,8 +61,8 @@ public class WorkSpaceSelectionCard extends WizardCard {
 		fileName.setWidth("410px");
 		fileName.setValue(saveResourceSession.getFileName());
 		
-		
-		p.add(new FieldLabel(fileName, "Name"), new VerticalLayoutData(1,
+	
+		p.add(new FieldLabel(fileName, msgs.nameLabel()), new VerticalLayoutData(1,
 				-1));
 
 		fileDescription = new TextField();
@@ -67,7 +70,7 @@ public class WorkSpaceSelectionCard extends WizardCard {
 		fileDescription.addValidator(new EmptyValidator<String>());
 		fileDescription.setWidth("410px");
 		fileDescription.setValue(saveResourceSession.getFileDescription());
-		p.add(new FieldLabel(fileDescription, "Description"),
+		p.add(new FieldLabel(fileDescription, msgs.descriptionLabel()),
 				new VerticalLayoutData(1, -1));
 		
 		///
@@ -77,8 +80,8 @@ public class WorkSpaceSelectionCard extends WizardCard {
 		List<ItemType> showableTypes = new ArrayList<ItemType>();
 		showableTypes.add(ItemType.FOLDER);
 		
-		wpanel = new WorkspaceExplorerSelectPanel(new String(
-				"Workspace Selection"),selectableTypes, showableTypes);
+		wpanel = new WorkspaceExplorerSelectPanel(
+				msgs.workspaceExplorerSelectionPanelHead(),selectableTypes, showableTypes);
 
 		WorskpaceExplorerSelectNotificationListener handler = new WorskpaceExplorerSelectNotificationListener() {
 
@@ -118,11 +121,15 @@ public class WorkSpaceSelectionCard extends WizardCard {
 		
 		
 		///
-		p.add(new FieldLabel(wpanel, "Folder"), new VerticalLayoutData(1, 1));
+		p.add(new FieldLabel(wpanel, msgs.workspaceExplorerSelectionPanelLabel()), new VerticalLayoutData(1, 1));
 	
 		setContent(formPanel);
 
 	}
+	
+	protected void initMessages(){
+		msgsCommon=GWT.create(CommonMessages.class);
+	}
 
 	protected void checkExportData() {
 		Log.debug("File Name:" + fileName.getCurrentValue() + " Item id: "
@@ -151,22 +158,22 @@ public class WorkSpaceSelectionCard extends WizardCard {
 							.getCurrentValue());
 					goNext();
 				} else {
-					d = new AlertMessageBox("Attention", "No folder selected");
+					d = new AlertMessageBox(msgsCommon.attention(), msgs.attentionNoFolderSelected());
 					d.addHideHandler(hideHandler);
 					d.setModal(false);
 					d.show();
 
 				}
 			} else {
-				d = new AlertMessageBox("Attention",
-						"No valid file description");
+				d = new AlertMessageBox(msgsCommon.attention(),
+						msgs.attentionNoValidFileDescription());
 				d.addHideHandler(hideHandler);
 				d.setModal(false);
 				d.show();
 
 			}
 		} else {
-			d = new AlertMessageBox("Attention", "No valid file name");
+			d = new AlertMessageBox(msgsCommon.attention(), msgs.attentionNoValidFileName());
 			d.addHideHandler(hideHandler);
 			d.setModal(false);
 			d.show();
